## Table of contents

- [surface](#surface)
- [onSurface](#onSurface)
- [interactive](#interactive)
- [secondary](#secondary)
- [primary](#primary)
- [critical](#critical)
- [warning](#warning)
- [highlight](#highlight)
- [success](#success)
- [decorative](#decorative)
- [Overrides](#Overrides)

## surface

[↑ Back to top](#table-of-contents)

The surface role is used for the backgrounds of the UI. With a light color scheme, surface colors are nearly white, while in a dark color scheme, surface colors are nearly black. The color passed to the surface role impacts the rest of the color roles and their variants, adjusting them for light or dark contexts.

| CSS variable                             | Description                                                                                                                           | Light mode                                                                                                                      | Dark mode                                                                                                                       |
| ---------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------- |
| <pre>--p-background</pre>                | For use as a background color, in components such as Page and Frame backgrounds.                                                      | ![](https://www.gifpng.com/64x64/f6f6f7/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#f6f6f7 | ![](https://www.gifpng.com/64x64/0b0c0d/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#0b0c0d |
| <pre>--p-background-hovered</pre>        | For use when an action or navigation is used on a background.                                                                         | ![](https://www.gifpng.com/64x64/f1f2f3/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#f1f2f3 | ![](https://www.gifpng.com/64x64/0b0c0d/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#0b0c0d |
| <pre>--p-background-pressed</pre>        | For use when an action or navigation is used on a background.                                                                         | ![](https://www.gifpng.com/64x64/edeeef/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#edeeef | ![](https://www.gifpng.com/64x64/0b0c0d/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#0b0c0d |
| <pre>--p-background-selected</pre>       | For use in the selected item in navigation                                                                                            | ![](https://www.gifpng.com/64x64/edeeef/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#edeeef | ![](https://www.gifpng.com/64x64/0b0c0d/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#0b0c0d |
| <pre>--p-surface</pre>                   | For use as a background color, in components such as Card, Modal, and Popover.                                                        | ![](https://www.gifpng.com/64x64/ffffff/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#ffffff | ![](https://www.gifpng.com/64x64/202123/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#202123 |
| <pre>--p-surface-neutral</pre>           | For use as a background color in neutral badges.                                                                                      | ![](https://www.gifpng.com/64x64/e4e5e7/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#e4e5e7 | ![](https://www.gifpng.com/64x64/313335/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#313335 |
| <pre>--p-surface-neutral-hovered</pre>   | For use as a hovered background color in neutral badges.                                                                              | ![](https://www.gifpng.com/64x64/dbdddf/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#dbdddf | ![](https://www.gifpng.com/64x64/313335/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#313335 |
| <pre>--p-surface-neutral-pressed</pre>   | For use as a pressed background color in neutral badges.                                                                              | ![](https://www.gifpng.com/64x64/c9ccd0/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#c9ccd0 | ![](https://www.gifpng.com/64x64/313335/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#313335 |
| <pre>--p-surface-neutral-disabled</pre>  | For use as a disabled background color in neutral badges.                                                                             | ![](https://www.gifpng.com/64x64/f1f2f3/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#f1f2f3 | ![](https://www.gifpng.com/64x64/313335/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#313335 |
| <pre>--p-surface-neutral-subdued</pre>   | For use as a background color in neutral banners.                                                                                     | ![](https://www.gifpng.com/64x64/f6f6f7/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#f6f6f7 | ![](https://www.gifpng.com/64x64/44474a/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#44474a |
| <pre>--p-surface-subdued</pre>           | For use as a subdued background color, in components such as Card, Modal, and Popover.                                                | ![](https://www.gifpng.com/64x64/fafbfb/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#fafbfb | ![](https://www.gifpng.com/64x64/1a1c1d/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#1a1c1d |
| <pre>--p-surface-disabled</pre>          | For use as a surface color on disabled interactive elements such as option list items and action list items when in a disabled state. | ![](https://www.gifpng.com/64x64/fafbfb/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#fafbfb | ![](https://www.gifpng.com/64x64/1a1c1d/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#1a1c1d |
| <pre>--p-surface-hovered</pre>           | For use as a surface color on interactive elements such as resource list items and action list items when in a hovered state.         | ![](https://www.gifpng.com/64x64/f6f6f7/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#f6f6f7 | ![](https://www.gifpng.com/64x64/2f3133/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#2f3133 |
| <pre>--p-surface-pressed</pre>           | For use as a surface color on interactive elements such as resource list items and action list items when in a pressed state.         | ![](https://www.gifpng.com/64x64/f1f2f3/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#f1f2f3 | ![](https://www.gifpng.com/64x64/3e4043/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#3e4043 |
| <pre>--p-surface-depressed</pre>         | For use as a surface color on interactive elements such as resource list items and action list items when in a depressed state.       | ![](https://www.gifpng.com/64x64/edeeef/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#edeeef | ![](https://www.gifpng.com/64x64/505356/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#505356 |
| <pre>--p-backdrop</pre>                  | For use as the background color of the backdrop component for navigation and modal. This color has an alpha of `0.5`.                 | ![](https://www.gifpng.com/64x64/000000/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#000000 | ![](https://www.gifpng.com/64x64/000000/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#000000 |
| <pre>--p-overlay</pre>                   | For use as the background color of elements which lay on top of surfaces to obscure their contents. This color has an alpha of `0.5`. | ![](https://www.gifpng.com/64x64/ffffff/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#ffffff | ![](https://www.gifpng.com/64x64/212121/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#212121 |
| <pre>--p-shadow-from-dim-light</pre>     | For use in building shadows for modals. This color has an alpha of `0.02`.                                                            | ![](https://www.gifpng.com/64x64/000000/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#000000 | ![](https://www.gifpng.com/64x64/ffffff/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#ffffff |
| <pre>--p-shadow-from-ambient-light</pre> | For use in building shadows for popovers, and cards. This color has an alpha of `0.05`.                                               | ![](https://www.gifpng.com/64x64/171818/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#171818 | ![](https://www.gifpng.com/64x64/171818/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#171818 |
| <pre>--p-shadow-from-direct-light</pre>  | For use in building shadows for popovers and cards. This color has an alpha of `0.15`.                                                | ![](https://www.gifpng.com/64x64/000000/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#000000 | ![](https://www.gifpng.com/64x64/ffffff/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#ffffff |
| <pre>--p-hint-from-direct-light</pre>    | For use in building shadows scrollables.                                                                                              | ![](https://www.gifpng.com/64x64/000000/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#000000 | ![](https://www.gifpng.com/64x64/b9b9b9/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#b9b9b9 |

---

## onSurface

[↑ Back to top](#table-of-contents)

The onSurface role is made up of elements which appear on top of a surface, including borders, secondary icons, and text. When a light surface is provided, onSurface values will be dark. When a dark surface is provided, onSurface values will be light.

| CSS variable                          | Description                                                                          | Light mode                                                                                                                      | Dark mode                                                                                                                       |
| ------------------------------------- | ------------------------------------------------------------------------------------ | ------------------------------------------------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------- |
| <pre>--p-on-surface-background</pre>  | For use as a background color, in components on surface elements such as SearchField | ![](https://www.gifpng.com/64x64/f1f2f3/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#f1f2f3 | ![](https://www.gifpng.com/64x64/2f3133/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#2f3133 |
| <pre>--p-border</pre>                 | For use as the default border on elements.                                           | ![](https://www.gifpng.com/64x64/8c9196/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#8c9196 | ![](https://www.gifpng.com/64x64/505356/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#505356 |
| <pre>--p-border-neutral-subdued</pre> | For use as the border on banners.                                                    | ![](https://www.gifpng.com/64x64/babfc3/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#babfc3 | ![](https://www.gifpng.com/64x64/82878b/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#82878b |
| <pre>--p-border-hovered</pre>         | Used for borders on hovered interactive elements                                     | ![](https://www.gifpng.com/64x64/999ea4/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#999ea4 | ![](https://www.gifpng.com/64x64/505356/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#505356 |
| <pre>--p-border-disabled</pre>        | Used for disabled borders on interactive elements                                    | ![](https://www.gifpng.com/64x64/d2d5d8/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#d2d5d8 | ![](https://www.gifpng.com/64x64/676b6f/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#676b6f |
| <pre>--p-border-subdued</pre>         | For use as a subdued border on elements.                                             | ![](https://www.gifpng.com/64x64/c9cccf/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#c9cccf | ![](https://www.gifpng.com/64x64/82878b/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#82878b |
| <pre>--p-border-depressed</pre>       | For use as a border on depressed elements.                                           | ![](https://www.gifpng.com/64x64/575959/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#575959 | ![](https://www.gifpng.com/64x64/8e9191/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#8e9191 |
| <pre>--p-border-shadow</pre>          | For use as an additional bottom border on elements.                                  | ![](https://www.gifpng.com/64x64/aeb4b9/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#aeb4b9 | ![](https://www.gifpng.com/64x64/5b5f62/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#5b5f62 |
| <pre>--p-border-shadow-subdued</pre>  | For use as an additional, subdued bottom border on elements.                         | ![](https://www.gifpng.com/64x64/babfc4/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#babfc4 | ![](https://www.gifpng.com/64x64/82878b/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#82878b |
| <pre>--p-divider</pre>                | For use as a divider between elements.                                               | ![](https://www.gifpng.com/64x64/e1e3e5/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#e1e3e5 | ![](https://www.gifpng.com/64x64/1a1c1d/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#1a1c1d |
| <pre>--p-icon</pre>                   | For use as the fill color of icons.                                                  | ![](https://www.gifpng.com/64x64/5c5f62/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#5c5f62 | ![](https://www.gifpng.com/64x64/a6acb2/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#a6acb2 |
| <pre>--p-icon-hovered</pre>           | For use as the fill color of hovered icons.                                          | ![](https://www.gifpng.com/64x64/1a1c1d/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#1a1c1d | ![](https://www.gifpng.com/64x64/e1e3e5/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#e1e3e5 |
| <pre>--p-icon-pressed</pre>           | For use as the fill color of pressed icons.                                          | ![](https://www.gifpng.com/64x64/44474a/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#44474a | ![](https://www.gifpng.com/64x64/a6acb2/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#a6acb2 |
| <pre>--p-icon-disabled</pre>          | For use as the fill color of disabled icons.                                         | ![](https://www.gifpng.com/64x64/babec3/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#babec3 | ![](https://www.gifpng.com/64x64/54575a/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#54575a |
| <pre>--p-icon-subdued</pre>           | For use as the fill color of subdued icons.                                          | ![](https://www.gifpng.com/64x64/8c9196/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#8c9196 | ![](https://www.gifpng.com/64x64/787d81/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#787d81 |
| <pre>--p-text</pre>                   | For use as a text color.                                                             | ![](https://www.gifpng.com/64x64/202223/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#202223 | ![](https://www.gifpng.com/64x64/e3e5e7/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#e3e5e7 |
| <pre>--p-text-disabled</pre>          | For use as a disabled text color and as a placeholder text color.                    | ![](https://www.gifpng.com/64x64/8c9196/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#8c9196 | ![](https://www.gifpng.com/64x64/6f7377/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#6f7377 |
| <pre>--p-text-subdued</pre>           | For use as a subdued text color.                                                     | ![](https://www.gifpng.com/64x64/6d7175/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#6d7175 | ![](https://www.gifpng.com/64x64/999fa4/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#999fa4 |

---

## interactive

[↑ Back to top](#table-of-contents)

The interactive role is used to express interactivity in components. It is used in links, as an indicator of focus, and as an indicator of selected interactive states.

| CSS variable                            | Description                                                                                                                        | Light mode                                                                                                                      | Dark mode                                                                                                                       |
| --------------------------------------- | ---------------------------------------------------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------- |
| <pre>--p-interactive</pre>              | Used for links, plain buttons, and as the fill color for selected checkboxes and radio buttons.                                    | ![](https://www.gifpng.com/64x64/2c6ecb/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#2c6ecb | ![](https://www.gifpng.com/64x64/36a3ff/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#36a3ff |
| <pre>--p-interactive-disabled</pre>     | Used for disabled links and plain buttons.                                                                                         | ![](https://www.gifpng.com/64x64/bdc1cc/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#bdc1cc | ![](https://www.gifpng.com/64x64/2662b6/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#2662b6 |
| <pre>--p-interactive-hovered</pre>      | Used for hovered links and plain buttons.                                                                                          | ![](https://www.gifpng.com/64x64/1f5199/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#1f5199 | ![](https://www.gifpng.com/64x64/67afff/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#67afff |
| <pre>--p-interactive-pressed</pre>      | Used for pressed links and plain buttons.                                                                                          | ![](https://www.gifpng.com/64x64/103262/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#103262 | ![](https://www.gifpng.com/64x64/88bcff/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#88bcff |
| <pre>--p-focused</pre>                  | For use in the focus ring on interactive elements.                                                                                 | ![](https://www.gifpng.com/64x64/458fff/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#458fff | ![](https://www.gifpng.com/64x64/2662b6/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#2662b6 |
| <pre>--p-surface-selected</pre>         | For use as a surface color in selected interactive elements, in components such as action list and resource list.                  | ![](https://www.gifpng.com/64x64/f2f7fe/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#f2f7fe | ![](https://www.gifpng.com/64x64/020e23/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#020e23 |
| <pre>--p-surface-selected-hovered</pre> | For use as a surface color in selected interactive elements that are hovered, in components such as action list and resource list. | ![](https://www.gifpng.com/64x64/edf4fe/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#edf4fe | ![](https://www.gifpng.com/64x64/071d3d/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#071d3d |
| <pre>--p-surface-selected-pressed</pre> | For use as a surface color in selected interactive elements that are pressed, in components such as action list and resource list. | ![](https://www.gifpng.com/64x64/e5effd/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#e5effd | ![](https://www.gifpng.com/64x64/0d2b56/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#0d2b56 |
| <pre>--p-icon-on-interactive</pre>      | For use as a fill color for icons on interactive elements.                                                                         | ![](https://www.gifpng.com/64x64/ffffff/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#ffffff | ![](https://www.gifpng.com/64x64/ffffff/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#ffffff |
| <pre>--p-text-on-interactive</pre>      | For use as a text color on interactive elements.                                                                                   | ![](https://www.gifpng.com/64x64/ffffff/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#ffffff | ![](https://www.gifpng.com/64x64/ffffff/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#ffffff |

---

## secondary

[↑ Back to top](#table-of-contents)

A secondary interactive color role, for use in secondary and tertiary buttons as a background color, as well as in form elements as a background color.

| CSS variable                              | Description                                                                                                                                   | Light mode                                                                                                                      | Dark mode                                                                                                                       |
| ----------------------------------------- | --------------------------------------------------------------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------- |
| <pre>--p-action-secondary</pre>           | Used for secondary buttons and tertiary buttons, as well as in form elements as a background color and pontentially other secondary surfaces. | ![](https://www.gifpng.com/64x64/ffffff/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#ffffff | ![](https://www.gifpng.com/64x64/4d5053/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#4d5053 |
| <pre>--p-action-secondary-disabled</pre>  | Used as a disabled state for secondary buttons                                                                                                | ![](https://www.gifpng.com/64x64/ffffff/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#ffffff | ![](https://www.gifpng.com/64x64/202223/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#202223 |
| <pre>--p-action-secondary-hovered</pre>   | Used as a hovered state for secondary buttons                                                                                                 | ![](https://www.gifpng.com/64x64/f6f6f7/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#f6f6f7 | ![](https://www.gifpng.com/64x64/54575b/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#54575b |
| <pre>--p-action-secondary-pressed</pre>   | Used as a pressed state for secondary buttons                                                                                                 | ![](https://www.gifpng.com/64x64/f1f2f3/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#f1f2f3 | ![](https://www.gifpng.com/64x64/606467/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#606467 |
| <pre>--p-action-secondary-depressed</pre> | Used as a depressed state for secondary buttons                                                                                               | ![](https://www.gifpng.com/64x64/6d7175/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#6d7175 | ![](https://www.gifpng.com/64x64/7b7f84/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#7b7f84 |

---

## primary

[↑ Back to top](#table-of-contents)

A primary interactive color, for use in primary buttons as a background color. Also used in navigation and tabs for icons, and for a surface color when in a selected state.

| CSS variable                                    | Description                                                                                                                                                             | Light mode                                                                                                                      | Dark mode                                                                                                                       |
| ----------------------------------------------- | ----------------------------------------------------------------------------------------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------- |
| <pre>--p-action-primary</pre>                   | Used as the background color for primary actions, and as the fill color for icons and the text color in navigation and tabs to communicate interaction states.          | ![](https://www.gifpng.com/64x64/008060/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#008060 | ![](https://www.gifpng.com/64x64/008060/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#008060 |
| <pre>--p-action-primary-disabled</pre>          | Used as the background color for disabled primary actions, and as the fill color for icons and the text color in navigation and tabs to communicate interaction states. | ![](https://www.gifpng.com/64x64/f1f1f1/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#f1f1f1 | ![](https://www.gifpng.com/64x64/005640/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#005640 |
| <pre>--p-action-primary-hovered</pre>           | Used as the background color for hovered primary actions, and as the fill color for icons and the text color in navigation and tabs to communicate interaction states.  | ![](https://www.gifpng.com/64x64/006e52/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#006e52 | ![](https://www.gifpng.com/64x64/009671/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#009671 |
| <pre>--p-action-primary-pressed</pre>           | Used as the background color for pressed primary actions, and as the fill color for icons and the text color in navigation and tabs to communicate interaction states.  | ![](https://www.gifpng.com/64x64/005e46/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#005e46 | ![](https://www.gifpng.com/64x64/00a47c/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#00a47c |
| <pre>--p-action-primary-depressed</pre>         | Used as the background color for pressed primary actions, and as the fill color for icons and the text color in navigation and tabs to communicate interaction states.  | ![](https://www.gifpng.com/64x64/003d2c/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#003d2c | ![](https://www.gifpng.com/64x64/00b388/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#00b388 |
| <pre>--p-icon-on-primary</pre>                  | For use as a fill color for icons on primary actions. Not for use in icons on navigation and tabs.                                                                      | ![](https://www.gifpng.com/64x64/ffffff/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#ffffff | ![](https://www.gifpng.com/64x64/e6fff4/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#e6fff4 |
| <pre>--p-text-on-primary</pre>                  | For use as a text color on primary actions. Not for use in text on navigation and tabs.                                                                                 | ![](https://www.gifpng.com/64x64/ffffff/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#ffffff | ![](https://www.gifpng.com/64x64/ffffff/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#ffffff |
| <pre>--p-surface-primary-selected</pre>         | Used as a surface color to indicate selected interactive states in navigation and tabs.                                                                                 | ![](https://www.gifpng.com/64x64/f1f8f5/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#f1f8f5 | ![](https://www.gifpng.com/64x64/0c1210/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#0c1210 |
| <pre>--p-surface-primary-selected-hovered</pre> | Used as a surface color to indicate selected interactive states that are hovered in navigation and tabs.                                                                | ![](https://www.gifpng.com/64x64/b3d0c3/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#b3d0c3 | ![](https://www.gifpng.com/64x64/28302c/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#28302c |
| <pre>--p-surface-primary-selected-pressed</pre> | Used as a surface color to indicate selected interactive states that are pressed in navigation and tabs.                                                                | ![](https://www.gifpng.com/64x64/a2bcb0/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#a2bcb0 | ![](https://www.gifpng.com/64x64/36403b/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#36403b |

---

## critical

[↑ Back to top](#table-of-contents)

Used to communicate destructive outcomes on interactive elements, for communicating errors, and to indicate a critical event in inert elements that requires immediate merchant action.

| CSS variable                                      | Description                                                                                                                                                                                                                                       | Light mode                                                                                                                      | Dark mode                                                                                                                       |
| ------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------- |
| <pre>--p-border-critical</pre>                    | For use as a border on critical components such as an outline on interactive elements in an error state.                                                                                                                                          | ![](https://www.gifpng.com/64x64/fd5749/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#fd5749 | ![](https://www.gifpng.com/64x64/e32f0e/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#e32f0e |
| <pre>--p-border-critical-subdued</pre>            | For use as a border on critical components such as banners.                                                                                                                                                                                       | ![](https://www.gifpng.com/64x64/e0b3b2/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#e0b3b2 | ![](https://www.gifpng.com/64x64/e32f0e/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#e32f0e |
| <pre>--p-border-critical-disabled</pre>           | For use as a disabled border on critical components such as banners, and as an outline on interactive elements in an error state.                                                                                                                 | ![](https://www.gifpng.com/64x64/ffa7a3/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#ffa7a3 | ![](https://www.gifpng.com/64x64/831704/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#831704 |
| <pre>--p-icon-critical</pre>                      | For use as an icon fill color on top of critical elements.                                                                                                                                                                                        | ![](https://www.gifpng.com/64x64/d72c0d/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#d72c0d | ![](https://www.gifpng.com/64x64/da2d0d/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#da2d0d |
| <pre>--p-surface-critical</pre>                   | For use as a surface color on critical elements including badges.                                                                                                                                                                                 | ![](https://www.gifpng.com/64x64/fed3d1/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#fed3d1 | ![](https://www.gifpng.com/64x64/450701/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#450701 |
| <pre>--p-surface-critical-subdued</pre>           | For use as a subdued surface color on critical elements including banners.                                                                                                                                                                        | ![](https://www.gifpng.com/64x64/fff4f4/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#fff4f4 | ![](https://www.gifpng.com/64x64/450701/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#450701 |
| <pre>--p-surface-critical-subdued-hovered</pre>   | For use as a surface color on critical interactive elements including action list items in a hovered state.                                                                                                                                       | ![](https://www.gifpng.com/64x64/fff0f0/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#fff0f0 | ![](https://www.gifpng.com/64x64/441714/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#441714 |
| <pre>--p-surface-critical-subdued-pressed</pre>   | For use as a surface color on critical interactive elements including action list items in a pressed state.                                                                                                                                       | ![](https://www.gifpng.com/64x64/ffe9e8/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#ffe9e8 | ![](https://www.gifpng.com/64x64/6b1003/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#6b1003 |
| <pre>--p-surface-critical-subdued-depressed</pre> | For use as a surface color on critical interactive elements including action list items in a depressed state.                                                                                                                                     | ![](https://www.gifpng.com/64x64/febcb9/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#febcb9 | ![](https://www.gifpng.com/64x64/871805/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#871805 |
| <pre>--p-text-critical</pre>                      | For use as a text color in inert critical elements such as exception list. Not for use as a text color on banners and badges.                                                                                                                     | ![](https://www.gifpng.com/64x64/d72c0d/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#d72c0d | ![](https://www.gifpng.com/64x64/e9807a/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#e9807a |
| <pre>--p-action-critical</pre>                    | For use as the background color for destructive buttons, and as the background color for error toast messages.                                                                                                                                    | ![](https://www.gifpng.com/64x64/d82c0d/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#d82c0d | ![](https://www.gifpng.com/64x64/cd290c/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#cd290c |
| <pre>--p-action-critical-disabled</pre>           | For use as the background color for disabled destructive buttons, and as the background color for error toast messages.                                                                                                                           | ![](https://www.gifpng.com/64x64/f1f1f1/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#f1f1f1 | ![](https://www.gifpng.com/64x64/bb250a/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#bb250a |
| <pre>--p-action-critical-hovered</pre>            | For use as the background color for hovered destructive buttons, and as the background color for error toast messages.                                                                                                                            | ![](https://www.gifpng.com/64x64/bc2200/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#bc2200 | ![](https://www.gifpng.com/64x64/e32f0e/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#e32f0e |
| <pre>--p-action-critical-pressed</pre>            | For use as the background color for pressed destructive buttons, and as the background color for error toast messages.                                                                                                                            | ![](https://www.gifpng.com/64x64/a21b00/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#a21b00 | ![](https://www.gifpng.com/64x64/fa3511/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#fa3511 |
| <pre>--p-action-critical-depressed</pre>          | For use as the background color for depressed destructive buttons, and as the background color for error toast messages.                                                                                                                          | ![](https://www.gifpng.com/64x64/6c0f00/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#6c0f00 | ![](https://www.gifpng.com/64x64/fd5749/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#fd5749 |
| <pre>--p-icon-on-critical</pre>                   | For use as a fill color for icons on critical actions.                                                                                                                                                                                            | ![](https://www.gifpng.com/64x64/ffffff/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#ffffff | ![](https://www.gifpng.com/64x64/fff8f7/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#fff8f7 |
| <pre>--p-text-on-critical</pre>                   | For use as a text color on critical actions.                                                                                                                                                                                                      | ![](https://www.gifpng.com/64x64/ffffff/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#ffffff | ![](https://www.gifpng.com/64x64/ffffff/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#ffffff |
| <pre>--p-interactive-critical</pre>               | For use as the text color for destructive interactive elements: links, plain buttons, error state of selected checkboxes and radio buttons, as well as a text color on destructive action list items. Not for use on critical banners and badges. | ![](https://www.gifpng.com/64x64/d82c0d/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#d82c0d | ![](https://www.gifpng.com/64x64/fd726a/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#fd726a |
| <pre>--p-interactive-critical-disabled</pre>      | For use as a text color in disabled destructive plain buttons, as well as a text color on destructive action list items. Not for use on critical banners and badges.                                                                              | ![](https://www.gifpng.com/64x64/fd938d/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#fd938d | ![](https://www.gifpng.com/64x64/feaca8/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#feaca8 |
| <pre>--p-interactive-critical-hovered</pre>       | For use as a text color in hovered destructive plain buttons, as well as a text color on destructive action list items. Not for use on critical banners and badges.                                                                               | ![](https://www.gifpng.com/64x64/cd290c/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#cd290c | ![](https://www.gifpng.com/64x64/fd8a84/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#fd8a84 |
| <pre>--p-interactive-critical-pressed</pre>       | For use as a text color in pressed destructive plain buttons, as well as a text color on destructive action list items. Not for use on critical banners and badges.                                                                               | ![](https://www.gifpng.com/64x64/670f03/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#670f03 | ![](https://www.gifpng.com/64x64/fd9f9b/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#fd9f9b |

---

## warning

[↑ Back to top](#table-of-contents)

For use as an indicator that action should be taken by merchants in components including badges, banners, and exception lists.

| CSS variable                                   | Description                                                                                                                   | Light mode                                                                                                                      | Dark mode                                                                                                                       |
| ---------------------------------------------- | ----------------------------------------------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------- |
| <pre>--p-border-warning</pre>                  | For use as a border on warning components such as...                                                                          | ![](https://www.gifpng.com/64x64/b98900/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#b98900 | ![](https://www.gifpng.com/64x64/997000/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#997000 |
| <pre>--p-border-warning-subdued</pre>          | For use as a border on warning components such as banners.                                                                    | ![](https://www.gifpng.com/64x64/e1b878/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#e1b878 | ![](https://www.gifpng.com/64x64/997000/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#997000 |
| <pre>--p-icon-warning</pre>                    | For use as an icon fill color on top of warning elements.                                                                     | ![](https://www.gifpng.com/64x64/b98900/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#b98900 | ![](https://www.gifpng.com/64x64/684b00/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#684b00 |
| <pre>--p-surface-warning</pre>                 | For use as a surface color on warning elements including badges.                                                              | ![](https://www.gifpng.com/64x64/ffd79d/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#ffd79d | ![](https://www.gifpng.com/64x64/997000/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#997000 |
| <pre>--p-surface-warning-subdued</pre>         | For use as a subdued surface color on warning elements including banners.                                                     | ![](https://www.gifpng.com/64x64/fff5ea/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#fff5ea | ![](https://www.gifpng.com/64x64/4d3b1d/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#4d3b1d |
| <pre>--p-surface-warning-subdued-hovered</pre> | For use as a subdued surface color on warning elements including banners.                                                     | ![](https://www.gifpng.com/64x64/fff2e2/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#fff2e2 | ![](https://www.gifpng.com/64x64/523f20/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#523f20 |
| <pre>--p-surface-warning-subdued-pressed</pre> | For use as a subdued surface color on warning elements including banners.                                                     | ![](https://www.gifpng.com/64x64/ffebd3/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#ffebd3 | ![](https://www.gifpng.com/64x64/574322/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#574322 |
| <pre>--p-text-warning</pre>                    | For use as a text color in inert critical elements such as exception list. Not for use as a text color on banners and badges. | ![](https://www.gifpng.com/64x64/916a00/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#916a00 | ![](https://www.gifpng.com/64x64/ca9500/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#ca9500 |

---

## highlight

[↑ Back to top](#table-of-contents)

Used to highlight elements of the UI that are important for merchants, but do not require immediate action. Used in information banners and badges, indicators that draw attention to new information, bars that indicate loading or progress, and in data visualization.

| CSS variable                                     | Description                                                                                                 | Light mode                                                                                                                      | Dark mode                                                                                                                       |
| ------------------------------------------------ | ----------------------------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------- |
| <pre>--p-border-highlight</pre>                  | For use as a border on informational components such as...                                                  | ![](https://www.gifpng.com/64x64/449da7/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#449da7 | ![](https://www.gifpng.com/64x64/449da7/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#449da7 |
| <pre>--p-border-highlight-subdued</pre>          | For use as a border on informational components such as banners.                                            | ![](https://www.gifpng.com/64x64/98c6cd/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#98c6cd | ![](https://www.gifpng.com/64x64/449da7/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#449da7 |
| <pre>--p-icon-highlight</pre>                    | For use as an icon fill color on top of informational elements.                                             | ![](https://www.gifpng.com/64x64/00a0ac/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#00a0ac | ![](https://www.gifpng.com/64x64/2c6c73/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#2c6c73 |
| <pre>--p-surface-highlight</pre>                 | For use as a surface color on information elements including badges.                                        | ![](https://www.gifpng.com/64x64/a4e8f2/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#a4e8f2 | ![](https://www.gifpng.com/64x64/006971/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#006971 |
| <pre>--p-surface-highlight-subdued</pre>         | For use as a surface color on information elements including banners.                                       | ![](https://www.gifpng.com/64x64/ebf9fc/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#ebf9fc | ![](https://www.gifpng.com/64x64/123539/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#123539 |
| <pre>--p-surface-highlight-subdued-hovered</pre> | For use as a surface color on information elements including banners.                                       | ![](https://www.gifpng.com/64x64/e4f7fa/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#e4f7fa | ![](https://www.gifpng.com/64x64/143a3e/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#143a3e |
| <pre>--p-surface-highlight-subdued-pressed</pre> | For use as a surface color on information elements including banners.                                       | ![](https://www.gifpng.com/64x64/d5f3f8/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#d5f3f8 | ![](https://www.gifpng.com/64x64/184146/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#184146 |
| <pre>--p-text-highlight</pre>                    | For use as a text color in inert informational elements. Not for use as a text color on banners and badges. | ![](https://www.gifpng.com/64x64/347c84/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#347c84 | ![](https://www.gifpng.com/64x64/a2effa/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#a2effa |

---

## success

[↑ Back to top](#table-of-contents)

Used to indicate the result of a successful action taken by a merchant, to indicate a positive event, or to illustrate growth.

| CSS variable                                   | Description                                                                                           | Light mode                                                                                                                      | Dark mode                                                                                                                       |
| ---------------------------------------------- | ----------------------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------- |
| <pre>--p-border-success</pre>                  | For use as a border on success components such as text inputs.                                        | ![](https://www.gifpng.com/64x64/00a47c/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#00a47c | ![](https://www.gifpng.com/64x64/008766/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#008766 |
| <pre>--p-border-success-subdued</pre>          | For use as a border on success components such as banners.                                            | ![](https://www.gifpng.com/64x64/95c9b4/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#95c9b4 | ![](https://www.gifpng.com/64x64/008766/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#008766 |
| <pre>--p-icon-success</pre>                    | For use as an icon fill color on top of success elements.                                             | ![](https://www.gifpng.com/64x64/007f5f/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#007f5f | ![](https://www.gifpng.com/64x64/005e46/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#005e46 |
| <pre>--p-surface-success</pre>                 | For use as a surface color on success elements including badges.                                      | ![](https://www.gifpng.com/64x64/aee9d1/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#aee9d1 | ![](https://www.gifpng.com/64x64/005e46/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#005e46 |
| <pre>--p-surface-success-subdued</pre>         | For use as a surface color on information elements including banners.                                 | ![](https://www.gifpng.com/64x64/f1f8f5/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#f1f8f5 | ![](https://www.gifpng.com/64x64/1c352c/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#1c352c |
| <pre>--p-surface-success-subdued-hovered</pre> | For use as a surface color on information elements including banners.                                 | ![](https://www.gifpng.com/64x64/ecf6f1/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#ecf6f1 | ![](https://www.gifpng.com/64x64/1f3a30/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#1f3a30 |
| <pre>--p-surface-success-subdued-pressed</pre> | For use as a surface color on information elements including banners.                                 | ![](https://www.gifpng.com/64x64/e2f1ea/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#e2f1ea | ![](https://www.gifpng.com/64x64/234136/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#234136 |
| <pre>--p-text-success</pre>                    | For use as a text color in inert success elements. Not for use as a text color on banners and badges. | ![](https://www.gifpng.com/64x64/008060/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#008060 | ![](https://www.gifpng.com/64x64/58ad8e/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#58ad8e |

---

## decorative

[↑ Back to top](#table-of-contents)

Used to decorate elements where color does convey a specific meaning in components like avatars

| CSS variable                            | Description                                                                 | Light mode                                                                                                                      | Dark mode                                                                                                                       |
| --------------------------------------- | --------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------- |
| <pre>--p-decorative-one-icon</pre>      | For use as a decorative icon color that is applied on a decorative surface. | ![](https://www.gifpng.com/64x64/7e5700/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#7e5700 | ![](https://www.gifpng.com/64x64/ffba43/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#ffba43 |
| <pre>--p-decorative-one-surface</pre>   | For use as a decorative surface color.                                      | ![](https://www.gifpng.com/64x64/ffc96b/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#ffc96b | ![](https://www.gifpng.com/64x64/8e6609/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#8e6609 |
| <pre>--p-decorative-one-text</pre>      | For use as a decorative text color that is applied on a decorative surface. | ![](https://www.gifpng.com/64x64/3d2800/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#3d2800 | ![](https://www.gifpng.com/64x64/ffffff/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#ffffff |
| <pre>--p-decorative-two-icon</pre>      | For use as a decorative icon color that is applied on a decorative surface. | ![](https://www.gifpng.com/64x64/af294e/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#af294e | ![](https://www.gifpng.com/64x64/f5b6c0/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#f5b6c0 |
| <pre>--p-decorative-two-surface</pre>   | For use as a decorative surface color.                                      | ![](https://www.gifpng.com/64x64/ffc4b0/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#ffc4b0 | ![](https://www.gifpng.com/64x64/ce5814/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#ce5814 |
| <pre>--p-decorative-two-text</pre>      | For use as a decorative text color that is applied on a decorative surface. | ![](https://www.gifpng.com/64x64/490b1c/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#490b1c | ![](https://www.gifpng.com/64x64/ffffff/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#ffffff |
| <pre>--p-decorative-three-icon</pre>    | For use as a decorative icon color that is applied on a decorative surface. | ![](https://www.gifpng.com/64x64/006d41/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#006d41 | ![](https://www.gifpng.com/64x64/00e38d/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#00e38d |
| <pre>--p-decorative-three-surface</pre> | For use as a decorative surface color.                                      | ![](https://www.gifpng.com/64x64/92e6b5/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#92e6b5 | ![](https://www.gifpng.com/64x64/007c5a/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#007c5a |
| <pre>--p-decorative-three-text</pre>    | For use as a decorative text color that is applied on a decorative surface. | ![](https://www.gifpng.com/64x64/002f19/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#002f19 | ![](https://www.gifpng.com/64x64/ffffff/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#ffffff |
| <pre>--p-decorative-four-icon</pre>     | For use as a decorative icon color that is applied on a decorative surface. | ![](https://www.gifpng.com/64x64/006a68/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#006a68 | ![](https://www.gifpng.com/64x64/00ddda/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#00ddda |
| <pre>--p-decorative-four-surface</pre>  | For use as a decorative surface color.                                      | ![](https://www.gifpng.com/64x64/91e0d6/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#91e0d6 | ![](https://www.gifpng.com/64x64/167c79/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#167c79 |
| <pre>--p-decorative-four-text</pre>     | For use as a decorative text color that is applied on a decorative surface. | ![](https://www.gifpng.com/64x64/002d2d/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#002d2d | ![](https://www.gifpng.com/64x64/ffffff/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#ffffff |
| <pre>--p-decorative-five-icon</pre>     | For use as a decorative icon color that is applied on a decorative surface. | ![](https://www.gifpng.com/64x64/ae2b4c/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#ae2b4c | ![](https://www.gifpng.com/64x64/f4b7bf/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#f4b7bf |
| <pre>--p-decorative-five-surface</pre>  | For use as a decorative surface color.                                      | ![](https://www.gifpng.com/64x64/fdc9d0/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#fdc9d0 | ![](https://www.gifpng.com/64x64/c23356/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#c23356 |
| <pre>--p-decorative-five-text</pre>     | For use as a decorative text color that is applied on a decorative surface. | ![](https://www.gifpng.com/64x64/4f0e1f/FFFFFF?border-width=16&border-type=rectangle&border-color=f6f6f7&text=%20)<br />#4f0e1f | ![](https://www.gifpng.com/64x64/ffffff/FFFFFF?border-width=16&border-type=rectangle&border-color=0b0c0d&text=%20)<br />#ffffff |

---

## Overrides

[↑ Back to top](#table-of-contents)

| CSS variable                              | Value                                                                                                        |
| ----------------------------------------- | ------------------------------------------------------------------------------------------------------------ |
| `--p-border-radius-base`                  | `0.4rem`                                                                                                     |
| `--p-border-radius-wide`                  | `0.8rem`                                                                                                     |
| `--p-border-radius-full`                  | `50%`                                                                                                        |
| `--p-card-shadow`                         | `0px 0px 5px var(--p-shadow-from-ambient-light), 0px 1px 2px var(--p-shadow-from-direct-light)`              |
| `--p-popover-shadow`                      | `-1px 0px 20px var(--p-shadow-from-ambient-light), 0px 1px 5px var(--p-shadow-from-direct-light)`            |
| `--p-modal-shadow`                        | `0px 26px 80px var(--p-shadow-from-dim-light), 0px 0px 1px var(--p-shadow-from-dim-light)`                   |
| `--p-top-bar-shadow`                      | `0 2px 2px -1px var(--p-shadow-from-direct-light)`                                                           |
| `--p-button-drop-shadow`                  | `0 1px 0 rgba(0, 0, 0, 0.05)`                                                                                |
| `--p-button-inner-shadow`                 | `inset 0 -1px 0 rgba(0, 0, 0, 0.2)`                                                                          |
| `--p-button-pressed-inner-shadow`         | `inset 0 1px 0 rgba(0, 0, 0, 0.15)`                                                                          |
| `--p-override-none`                       | `none`                                                                                                       |
| `--p-override-transparent`                | `transparent`                                                                                                |
| `--p-override-one`                        | `1`                                                                                                          |
| `--p-override-visible`                    | `visible`                                                                                                    |
| `--p-override-zero`                       | `0`                                                                                                          |
| `--p-override-loading-z-index`            | `514`                                                                                                        |
| `--p-button-font-weight`                  | `500`                                                                                                        |
| `--p-non-null-content`                    | `''`                                                                                                         |
| `--p-choice-size`                         | `2rem`                                                                                                       |
| `--p-icon-size`                           | `1rem`                                                                                                       |
| `--p-choice-margin`                       | `0.1rem`                                                                                                     |
| `--p-control-border-width`                | `0.2rem`                                                                                                     |
| `--p-banner-border-default`               | `inset 0 0.1rem 0 0 var(--p-border-neutral-subdued), inset 0 0 0 0.1rem var(--p-border-neutral-subdued)`     |
| `--p-banner-border-success`               | `inset 0 0.1rem 0 0 var(--p-border-success-subdued), inset 0 0 0 0.1rem var(--p-border-success-subdued)`     |
| `--p-banner-border-highlight`             | `inset 0 0.1rem 0 0 var(--p-border-highlight-subdued), inset 0 0 0 0.1rem var(--p-border-highlight-subdued)` |
| `--p-banner-border-warning`               | `inset 0 0.1rem 0 0 var(--p-border-warning-subdued), inset 0 0 0 0.1rem var(--p-border-warning-subdued)`     |
| `--p-banner-border-critical`              | `inset 0 0.1rem 0 0 var(--p-border-critical-subdued), inset 0 0 0 0.1rem var(--p-border-critical-subdued)`   |
| `--p-badge-mix-blend-mode`                | `luminosity`                                                                                                 |
| `--p-thin-border-subdued`                 | `0.1rem solid var(--p-border-subdued)`                                                                       |
| `--p-text-field-spinner-offset`           | `0.2rem`                                                                                                     |
| `--p-text-field-focus-ring-offset`        | `-0.4rem`                                                                                                    |
| `--p-text-field-focus-ring-border-radius` | `0.7rem`                                                                                                     |
| `--p-button-group-item-spacing`           | `-0.1rem`                                                                                                    |
| `--p-duration-1-0-0`                      | `100ms`                                                                                                      |
| `--p-duration-1-5-0`                      | `150ms`                                                                                                      |
| `--p-ease-in`                             | `cubic-bezier(0.5, 0.1, 1, 1)`                                                                               |
| `--p-ease`                                | `cubic-bezier(0.4, 0.22, 0.28, 1)`                                                                           |
| `--p-range-slider-thumb-size-base`        | `1.6rem`                                                                                                     |
| `--p-range-slider-thumb-size-active`      | `2.4rem`                                                                                                     |
| `--p-range-slider-thumb-scale`            | `1.5`                                                                                                        |
| `--p-badge-font-weight`                   | `400`                                                                                                        |
